@@ -72,31 +72,31 @@ class Client(object):
         self._refresh_token = user_login["refreshToken"]
         self._api.set_bearer_token(self._refresh_token)
 
-    async def refresh_token(self) -> None:
-        """FIXME: user_refresh_token doesn't seem to work once token is expired..."""
-        if self._token is None:
-            raise UhooError("Error cannot refresh token prior to logging in")
+    # async def refresh_token(self) -> None:
+    #     """FIXME: user_refresh_token doesn't seem to work once token is expired..."""
+    #     if self._token is None:
+    #         raise UhooError("Error cannot refresh token prior to logging in")
 
-        try:
-            user_refresh_token: dict = await self._api.user_refresh_token(
-                self._token, self._device_id
-            )
+    #     try:
+    #         user_refresh_token: dict = await self._api.user_refresh_token(
+    #             self._token, self._device_id
+    #         )
 
-            self._log.debug(
-                f"[user_refresh_token] returned\n{json_pp(user_refresh_token)}"
-            )
+    #         self._log.debug(
+    #             f"[user_refresh_token] returned\n{json_pp(user_refresh_token)}"
+    #         )
 
-            self._token = user_refresh_token["token"]
-            self._refresh_token = user_refresh_token["refreshToken"]
-            self._api.set_bearer_token(self._refresh_token)
+    #         self._token = user_refresh_token["token"]
+    #         self._refresh_token = user_refresh_token["refreshToken"]
+    #         self._api.set_bearer_token(self._refresh_token)
 
-        except UnauthorizedError:
-            self._log.debug(
-                "\033[91m"
-                + "[refresh_token] received 401 error, attempting to re-login"
-                + "\033[0m"
-            )
-            await self.login()
+    #     except UnauthorizedError:
+    #         self._log.debug(
+    #             "\033[91m"
+    #             + "[refresh_token] received 401 error, attempting to re-login"
+    #             + "\033[0m"
+    #         )
+    #         await self.login()
 
     async def get_latest_data(self) -> None:
         await self.login()
@@ -108,16 +108,12 @@ class Client(object):
                 + "[get_latest_data] received 401 error, refreshing token and trying again"
                 + "\033[0m"
             )
-            await self.refresh_token()
-            data_latest = await self._api.data_latest_aqi()
         except ForbiddenError:
             self._log.debug(
                 "\033[93m"
                 + "[get_latest_data] received 403 error, refreshing token and trying again"
                 + "\033[0m"
             )
-            await self.refresh_token()
-            data_latest = await self._api.data_latest_aqi()
 
     async def get_data(self) -> None:
         try:
